==> osb-plugin-3.6.0-sources.jar: com/xebialabs/deployit/plugin/osb/container/Domain.java <==
package com.xebialabs.deployit.plugin.osb.container;

import static com.google.common.collect.Sets.newHashSet;
import static com.xebialabs.deployit.plugin.api.udm.Metadata.ConfigurationItemRoot.INFRASTRUCTURE;
import static com.xebialabs.overthere.local.LocalConnection.getLocalConnection;
import static java.util.Collections.emptySet;

import java.util.Set;

import com.google.common.collect.ImmutableMap;
import com.xebialabs.deployit.plugin.api.udm.Metadata;
import com.xebialabs.deployit.plugin.api.udm.Property;
import com.xebialabs.deployit.plugin.osb.freemarker.TemplateEvaluator;
import com.xebialabs.deployit.plugin.overthere.Host;
import com.xebialabs.deployit.plugin.wls.container.Server;
import com.xebialabs.deployit.plugin.wls.container.WlsContainer;
import com.xebialabs.overthere.CmdLine;
import com.xebialabs.overthere.OperatingSystemFamily;
import com.xebialabs.overthere.OverthereFile;

@SuppressWarnings("serial")
@Metadata(root = INFRASTRUCTURE)
public class Domain extends com.xebialabs.deployit.plugin.wls.container.Domain implements WlsContainer {

	@SuppressWarnings("unused")
	@Property(required = true, defaultValue = "osb/runtime", hidden = true)
	private String pythonRuntimePath;

	@Property(required = true, defaultValue = "osb", hidden = true, description = "Path containing the wlst templates: wlst.sh.ftl (Unix) and wlst.cmd.ftl (Windows)")
	private String wlstTemplatePath;

	@Override
	public CmdLine getScriptCommandLine(OverthereFile script) {
		final String templatePath;
		final OverthereFile remoteWlst;
		final CmdLine cmdLine = new CmdLine();

		final OverthereFile localTemp = getLocalConnection().getTempFile("osb_plugin", ".tmp");
		if (getHost().getOs() == OperatingSystemFamily.UNIX) {
			templatePath = wlstTemplatePath + "/wlst.sh.ftl";
			remoteWlst = script.getParentFile().getFile("wlst.sh");
			cmdLine.addArgument("sh");
		} else {
			templatePath = wlstTemplatePath + "/wlst.cmd.ftl";
			remoteWlst = script.getParentFile().getFile("wlst.cmd");
		}

		cmdLine.addArgument(remoteWlst.getPath());
		TemplateEvaluator.evaluateTemplate(localTemp, templatePath, ImmutableMap.<String, Object> of("container", this, "script", script.getPath()));
		localTemp.copyTo(remoteWlst);

		return cmdLine;
	}

	@Override
	public String getRuntimePath() {
		return getProperty("pythonRuntimePath");
	}

	@Override
	public com.xebialabs.deployit.plugin.wls.container.Domain getDomain() {
		return this;
	}

	@Override
	public String getObjectName() {
		return "";
	}

	@Override
	public Set<Host> getHosts() {
		return newHashSet(getHost());
	}

	@Override
	public Set<Server> getServers() {
		return emptySet();
	}
}

==> osb-plugin-3.7.0-sources.jar: com/xebialabs/deployit/plugin/osb/container/Domain.java <==
package com.xebialabs.deployit.plugin.osb.container;

import java.util.Set;

import com.google.common.collect.ImmutableMap;
import com.xebialabs.deployit.plugin.api.udm.Metadata;
import com.xebialabs.deployit.plugin.api.udm.Property;
import com.xebialabs.deployit.plugin.osb.freemarker.TemplateEvaluator;
import com.xebialabs.deployit.plugin.overthere.Host;
import com.xebialabs.deployit.plugin.wls.container.Server;
import com.xebialabs.deployit.plugin.wls.container.WlsContainer;
import com.xebialabs.overthere.CmdLine;
import com.xebialabs.overthere.OperatingSystemFamily;
import com.xebialabs.overthere.OverthereFile;

import static com.google.common.collect.Sets.newHashSet;
import static com.xebialabs.deployit.plugin.api.udm.Metadata.ConfigurationItemRoot.INFRASTRUCTURE;
import static com.xebialabs.overthere.local.LocalConnection.getLocalConnection;
import static java.util.Collections.emptySet;

@SuppressWarnings("serial")
@Metadata(root = INFRASTRUCTURE,  description="OSB domain on the WebLogic server")
public class Domain extends com.xebialabs.deployit.plugin.wls.container.Domain implements WlsContainer {

	@SuppressWarnings("unused")
	@Property(required = true, defaultValue = "osb/runtime", hidden = true)
	private String pythonRuntimePath;

	@Property(required = true, defaultValue = "osb", hidden = true, description = "Path containing the wlst templates: wlst.sh.ftl (Unix) and wlst.cmd.ftl (Windows)")
	private String wlstTemplatePath;

	@Override
	public CmdLine getScriptCommandLine(OverthereFile script) {
		final String templatePath;
		final OverthereFile remoteWlst;
		final CmdLine cmdLine = new CmdLine();

		final OverthereFile localTemp = getLocalConnection().getTempFile("osb_plugin", ".tmp");
		if (getHost().getOs() == OperatingSystemFamily.UNIX) {
			templatePath = wlstTemplatePath + "/wlst.sh.ftl";
			remoteWlst = script.getParentFile().getFile("wlst.sh");
			cmdLine.addArgument("sh");
		} else {
			templatePath = wlstTemplatePath + "/wlst.cmd.ftl";
			remoteWlst = script.getParentFile().getFile("wlst.cmd");
		}

		cmdLine.addArgument(remoteWlst.getPath());
		TemplateEvaluator.evaluateTemplate(localTemp, templatePath, ImmutableMap.<String, Object> of("container", this, "script", script.getPath()));
		localTemp.copyTo(remoteWlst);

		return cmdLine;
	}

	@Override
	public String getRuntimePath() {
		return getProperty("pythonRuntimePath");
	}

	@Override
	public com.xebialabs.deployit.plugin.wls.container.Domain getDomain() {
		return this;
	}

	@Override
	public String getObjectName() {
		return "";
	}

	@Override
	public Set<Host> getHosts() {
		return newHashSet(getHost());
	}

	@Override
	public Set<Server> getServers() {
		return emptySet();
	}
}
